@@ -74,7 +74,8 @@ class TestRunner(TemplateMixin, TestSuite):
 
         self.title = title or (self.LANG == "cn" and self.DEFAULT_TITLE or self.DEFAULT_TITLE_en)
         self.description = description or (
-                self.LANG == "cn" and self.DEFAULT_DESCRIPTION or self.DEFAULT_DESCRIPTION_en)
+                self.LANG == "cn" and self.DEFAULT_DESCRIPTION or self.DEFAULT_DESCRIPTION_en
+        )
 
         self.thread_count = thread_count
         self.thread_start_wait = thread_start_wait
@@ -94,8 +95,7 @@ class TestRunner(TemplateMixin, TestSuite):
 
         logging.getLogger().addHandler(HandlerFactory.get_rotating_file_handler(self.log_file_name))
 
-        self.startTime = datetime.datetime.now()
-        self.stopTime = datetime.datetime.now()
+        self.stopTime = self.startTime = datetime.datetime.now()
 
         if tries < 0:
             raise ValueError((lang == "cn"
@@ -116,8 +116,9 @@ class TestRunner(TemplateMixin, TestSuite):
         self.tries, self.delay, self.back_off, self.max_delay, self.retry = tries, delay, back_off, max_delay, retry
         self.tc_dict = Manager().dict()
 
-    def _threadPoolExecutorTestCase(self, tmp_list, result):
+    def _thread_pool_executor_test_case(self, tmp_list, result):
         """多线程运行"""
+        t_list = []
         with ThreadPoolExecutor(self.thread_count) as pool:
             for test_case in tmp_list:
                 if _isnotsuite(test_case):
@@ -129,13 +130,15 @@ class TestRunner(TemplateMixin, TestSuite):
                     if (getattr(test_case.__class__, "_classSetupFailed", False) or
                             getattr(result, "_moduleSetUpFailed", False)):
                         continue
-                pool.submit(test_case, result)
+                while len(t_list) == self.thread_count:
+                    [t_list.remove(t) for t in t_list if t.done()]
+                t_list.append(pool.submit(test_case, result))
 
                 self.tc_dict[test_case.__class__] -= 1
                 if self.tc_dict[test_case.__class__] == 0:
                     self._tearDownPreviousClass(None, result)
 
-                time.sleep(self.thread_start_wait)
+                # time.sleep(self.thread_start_wait)
 
         self._handleModuleTearDown(result)
 
@@ -149,7 +152,8 @@ class TestRunner(TemplateMixin, TestSuite):
         if debug:
             logging.getLogger().setLevel(logging.DEBUG)
 
-        result = Result(self.LANG, self.tries, self.delay, self.back_off, self.max_delay, self.retry)
+        result = Result(self.LANG, self.tries, self.delay, self.back_off, self.max_delay, self.retry,
+                        self.thread_start_wait)
         if self.LANG == "cn":
             logging.info(f"预计并发线程数：{str(self.thread_count)}")
         else:
@@ -165,26 +169,26 @@ class TestRunner(TemplateMixin, TestSuite):
         if self.sequential_execution:
             # 执行套件添加顺序
             test_case_queue = queue.Queue()
-            L = []
+            test_case_arr = []
             tmp_key = None
             for test_case in test:
                 tmp_class_name = test_case.__class__
                 if tmp_key == tmp_class_name:
-                    L.append(test_case)
+                    test_case_arr.append(test_case)
                 else:
                     tmp_key = tmp_class_name
-                    if len(L) != 0:
-                        test_case_queue.put(L.copy())
-                        L.clear()
-                    L.append(test_case)
-            if len(L) != 0:
-                test_case_queue.put(L.copy())
+                    if len(test_case_arr) != 0:
+                        test_case_queue.put(test_case_arr.copy())
+                        test_case_arr.clear()
+                    test_case_arr.append(test_case)
+            if len(test_case_arr) != 0:
+                test_case_queue.put(test_case_arr.copy())
             while not test_case_queue.empty():
                 tmp_list = test_case_queue.get()
-                self._threadPoolExecutorTestCase(tmp_list, result)
+                self._thread_pool_executor_test_case(tmp_list, result)
         else:
             # 无序执行
-            self._threadPoolExecutorTestCase(test, result)
+            self._thread_pool_executor_test_case(test, result)
 
         self.stopTime = datetime.datetime.now()
         if result.stdout_steams.getvalue().strip():
@@ -207,13 +211,13 @@ class TestRunner(TemplateMixin, TestSuite):
             skip=result.skip_count,
             error=result.error_count
         )
-        self._generateReport(result)
+        self._generate_report(result)
         logging.info(s)
 
         return result
 
     @staticmethod
-    def _sortResult(result_list):
+    def _sort_result(result_list):
         """unittest不以任何特定的顺序运行。在这里把它们按类分组。"""
         remap = {}
         classes = []
@@ -231,16 +235,20 @@ class TestRunner(TemplateMixin, TestSuite):
                 classes.append(cls)
             remap[cls].append((n, t, o, i, r, s))
 
-        r = [(cls, remap[cls]) for cls in classes]
-        return r
+        result = []
+        for cls in classes:
+            re = remap[cls]
+            re = sorted(re, key=lambda x: str(x[1]))
+            result.append((cls, re))
+        return result
 
-    def _generateReport(self, result):
+    def _generate_report(self, result):
         """生成报告"""
         generator = f"HTMLReport {__author__} {__version__}"
         stylesheet = self._generate_stylesheet()
         heading = self._generate_heading(result)
         log_file = self._generate_log(self.log_name)
-        report = self._generate_report(result)
+        report = self._create_report(result)
 
         ending = self._generate_ending()
         js = self._generate_js()
@@ -277,11 +285,11 @@ class TestRunner(TemplateMixin, TestSuite):
         )
         return heading
 
-    def _generate_report(self, result):
+    def _create_report(self, result):
         rows = []
         nrs = 0
-        sortedResult = self._sortResult(result.result)
-        for cid, (cls, cls_results) in enumerate(sortedResult):
+        sorted_result = self._sort_result(result.result)
+        for cid, (cls, cls_results) in enumerate(sorted_result):
             np = nf = ne = ns = nr = 0
             for n, t, o, i, r, s in cls_results:
                 if n == 0:
